Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type VaultServiceLister ¶
type VaultServiceLister interface {
// List lists all VaultServices in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.VaultService, err error)
// VaultServices returns an object that can list and get VaultServices.
VaultServices(namespace string) VaultServiceNamespaceLister
VaultServiceListerExpansion
}
VaultServiceLister helps list VaultServices.
func NewVaultServiceLister ¶
func NewVaultServiceLister(indexer cache.Indexer) VaultServiceLister
NewVaultServiceLister returns a new VaultServiceLister.
type VaultServiceListerExpansion ¶
type VaultServiceListerExpansion interface{}
VaultServiceListerExpansion allows custom methods to be added to VaultServiceLister.
type VaultServiceNamespaceLister ¶
type VaultServiceNamespaceLister interface {
// List lists all VaultServices in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.VaultService, err error)
// Get retrieves the VaultService from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.VaultService, error)
VaultServiceNamespaceListerExpansion
}
VaultServiceNamespaceLister helps list and get VaultServices.
type VaultServiceNamespaceListerExpansion ¶
type VaultServiceNamespaceListerExpansion interface{}
VaultServiceNamespaceListerExpansion allows custom methods to be added to VaultServiceNamespaceLister.
Click to show internal directories.
Click to hide internal directories.